# coding: utf-8

"""
    Mantium API

    Mantium API Documentation  # noqa: E501

    The version of the OpenAPI document: 1.0.976
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from mantium_spec.api_client import ApiClient
from mantium_spec.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class ApplicationsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_application_detail(self, application_id, **kwargs):  # noqa: E501
        """Get application detail.  # noqa: E501

        Get the detail of an application.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_application_detail(application_id, async_req=True)
        >>> result = thread.get()

        :param application_id: (required)
        :type application_id: str
        :param body:
        :type body: object
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResponseGetApplicationDetail
        """
        kwargs['_return_http_data_only'] = True
        return self.get_application_detail_with_http_info(application_id, **kwargs)  # noqa: E501

    def get_application_detail_with_http_info(self, application_id, **kwargs):  # noqa: E501
        """Get application detail.  # noqa: E501

        Get the detail of an application.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_application_detail_with_http_info(application_id, async_req=True)
        >>> result = thread.get()

        :param application_id: (required)
        :type application_id: str
        :param body:
        :type body: object
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResponseGetApplicationDetail, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'application_id',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_application_detail" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'application_id' is set
        if self.api_client.client_side_validation and local_var_params.get('application_id') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `application_id` when calling `get_application_detail`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'application_id' in local_var_params:
            path_params['application_id'] = local_var_params['application_id']  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json'],
                'GET', body_params))  # noqa: E501
        if content_types_list:
                header_params['Content-Type'] = content_types_list

        # Authentication setting
        auth_settings = ['HTTPBearer']  # noqa: E501

        response_types_map = {
            200: "ResponseGetApplicationDetail",
            422: "HTTPValidationError",
        }

        return self.api_client.call_api(
            '/applications/{application_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def list_applications(self, **kwargs):  # noqa: E501
        """List applications.  # noqa: E501

        List applications ordered by creation date, paginated.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_applications(async_req=True)
        >>> result = thread.get()

        :param name:
        :type name: str
        :param status:
        :type status: ApplicationStatus
        :param cursor:
        :type cursor: str
        :param size:
        :type size: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CursorDatamodelPageApplicationResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.list_applications_with_http_info(**kwargs)  # noqa: E501

    def list_applications_with_http_info(self, **kwargs):  # noqa: E501
        """List applications.  # noqa: E501

        List applications ordered by creation date, paginated.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_applications_with_http_info(async_req=True)
        >>> result = thread.get()

        :param name:
        :type name: str
        :param status:
        :type status: ApplicationStatus
        :param cursor:
        :type cursor: str
        :param size:
        :type size: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CursorDatamodelPageApplicationResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'name',
            'status',
            'cursor',
            'size'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_applications" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and 'size' in local_var_params and local_var_params['size'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `size` when calling `list_applications`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if local_var_params.get('name') is not None:  # noqa: E501
            query_params.append(('name', local_var_params['name']))  # noqa: E501
        if local_var_params.get('status') is not None:  # noqa: E501
            query_params.append(('status', local_var_params['status']))  # noqa: E501
        if local_var_params.get('cursor') is not None:  # noqa: E501
            query_params.append(('cursor', local_var_params['cursor']))  # noqa: E501
        if local_var_params.get('size') is not None:  # noqa: E501
            query_params.append(('size', local_var_params['size']))  # noqa: E501

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['HTTPBearer']  # noqa: E501

        response_types_map = {
            200: "CursorDatamodelPageApplicationResponse",
            422: "HTTPValidationError",
        }

        return self.api_client.call_api(
            '/applications/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def query_application(self, application_id, application_top_k_query_request, **kwargs):  # noqa: E501
        """Interact with an application.  # noqa: E501

        Interact with an application  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.query_application(application_id, application_top_k_query_request, async_req=True)
        >>> result = thread.get()

        :param application_id: (required)
        :type application_id: str
        :param application_top_k_query_request: (required)
        :type application_top_k_query_request: ApplicationTopKQueryRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ApplicationQueryResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.query_application_with_http_info(application_id, application_top_k_query_request, **kwargs)  # noqa: E501

    def query_application_with_http_info(self, application_id, application_top_k_query_request, **kwargs):  # noqa: E501
        """Interact with an application.  # noqa: E501

        Interact with an application  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.query_application_with_http_info(application_id, application_top_k_query_request, async_req=True)
        >>> result = thread.get()

        :param application_id: (required)
        :type application_id: str
        :param application_top_k_query_request: (required)
        :type application_top_k_query_request: ApplicationTopKQueryRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ApplicationQueryResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'application_id',
            'application_top_k_query_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method query_application" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'application_id' is set
        if self.api_client.client_side_validation and local_var_params.get('application_id') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `application_id` when calling `query_application`")  # noqa: E501
        # verify the required parameter 'application_top_k_query_request' is set
        if self.api_client.client_side_validation and local_var_params.get('application_top_k_query_request') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `application_top_k_query_request` when calling `query_application`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'application_id' in local_var_params:
            path_params['application_id'] = local_var_params['application_id']  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if 'application_top_k_query_request' in local_var_params:
            body_params = local_var_params['application_top_k_query_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json'],
                'POST', body_params))  # noqa: E501
        if content_types_list:
                header_params['Content-Type'] = content_types_list

        # Authentication setting
        auth_settings = ['HTTPBearer']  # noqa: E501

        response_types_map = {
            200: "ApplicationQueryResponse",
            422: "HTTPValidationError",
        }

        return self.api_client.call_api(
            '/applications/{application_id}/query', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def query_chat_application(self, application_id, application_query_request, **kwargs):  # noqa: E501
        """Interact with a chat application.  # noqa: E501

        Interact with a chat application  This is an entirely different endpoint because deployments are keyed by path and we can't have two deployments with the same path.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.query_chat_application(application_id, application_query_request, async_req=True)
        >>> result = thread.get()

        :param application_id: (required)
        :type application_id: str
        :param application_query_request: (required)
        :type application_query_request: ApplicationQueryRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ApplicationChatResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.query_chat_application_with_http_info(application_id, application_query_request, **kwargs)  # noqa: E501

    def query_chat_application_with_http_info(self, application_id, application_query_request, **kwargs):  # noqa: E501
        """Interact with a chat application.  # noqa: E501

        Interact with a chat application  This is an entirely different endpoint because deployments are keyed by path and we can't have two deployments with the same path.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.query_chat_application_with_http_info(application_id, application_query_request, async_req=True)
        >>> result = thread.get()

        :param application_id: (required)
        :type application_id: str
        :param application_query_request: (required)
        :type application_query_request: ApplicationQueryRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ApplicationChatResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'application_id',
            'application_query_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method query_chat_application" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'application_id' is set
        if self.api_client.client_side_validation and local_var_params.get('application_id') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `application_id` when calling `query_chat_application`")  # noqa: E501
        # verify the required parameter 'application_query_request' is set
        if self.api_client.client_side_validation and local_var_params.get('application_query_request') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `application_query_request` when calling `query_chat_application`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'application_id' in local_var_params:
            path_params['application_id'] = local_var_params['application_id']  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if 'application_query_request' in local_var_params:
            body_params = local_var_params['application_query_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json'],
                'POST', body_params))  # noqa: E501
        if content_types_list:
                header_params['Content-Type'] = content_types_list

        # Authentication setting
        auth_settings = ['HTTPBearer']  # noqa: E501

        response_types_map = {
            200: "ApplicationChatResponse",
            422: "HTTPValidationError",
        }

        return self.api_client.call_api(
            '/applications/{application_id}/chat', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))



# coding: utf-8

"""
    Mantium API

    Mantium API Documentation  # noqa: E501

    The version of the OpenAPI document: 1.0.976
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from mantium_spec.configuration import Configuration


class RecipeManagementTemplateOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'is_activating': 'bool',
        'credentials': 'list[ApplicationCredential]'
    }

    attribute_map = {
        'type': 'type',
        'is_activating': 'is_activating',
        'credentials': 'credentials'
    }

    def __init__(self, type='recipe-management', is_activating=False, credentials=None, local_vars_configuration=None):  # noqa: E501
        """RecipeManagementTemplateOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._is_activating = None
        self._credentials = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if is_activating is not None:
            self.is_activating = is_activating
        if credentials is not None:
            self.credentials = credentials

    @property
    def type(self):
        """Gets the type of this RecipeManagementTemplateOptions.  # noqa: E501


        :return: The type of this RecipeManagementTemplateOptions.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this RecipeManagementTemplateOptions.


        :param type: The type of this RecipeManagementTemplateOptions.  # noqa: E501
        :type type: str
        """
        allowed_values = ["recipe-management"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def is_activating(self):
        """Gets the is_activating of this RecipeManagementTemplateOptions.  # noqa: E501


        :return: The is_activating of this RecipeManagementTemplateOptions.  # noqa: E501
        :rtype: bool
        """
        return self._is_activating

    @is_activating.setter
    def is_activating(self, is_activating):
        """Sets the is_activating of this RecipeManagementTemplateOptions.


        :param is_activating: The is_activating of this RecipeManagementTemplateOptions.  # noqa: E501
        :type is_activating: bool
        """

        self._is_activating = is_activating

    @property
    def credentials(self):
        """Gets the credentials of this RecipeManagementTemplateOptions.  # noqa: E501


        :return: The credentials of this RecipeManagementTemplateOptions.  # noqa: E501
        :rtype: list[ApplicationCredential]
        """
        return self._credentials

    @credentials.setter
    def credentials(self, credentials):
        """Sets the credentials of this RecipeManagementTemplateOptions.


        :param credentials: The credentials of this RecipeManagementTemplateOptions.  # noqa: E501
        :type credentials: list[ApplicationCredential]
        """

        self._credentials = credentials

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RecipeManagementTemplateOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RecipeManagementTemplateOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mantium API

    Mantium API Documentation  # noqa: E501

    The version of the OpenAPI document: 1.0.976
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from mantium_spec.configuration import Configuration


class ApplicationTopKQueryRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'query': 'str',
        'chat_session_id': 'str',
        'retriever_top_k': 'int',
        'reader_top_k': 'int'
    }

    attribute_map = {
        'query': 'query',
        'chat_session_id': 'chat_session_id',
        'retriever_top_k': 'retriever_top_k',
        'reader_top_k': 'reader_top_k'
    }

    def __init__(self, query=None, chat_session_id=None, retriever_top_k=10, reader_top_k=5, local_vars_configuration=None):  # noqa: E501
        """ApplicationTopKQueryRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._query = None
        self._chat_session_id = None
        self._retriever_top_k = None
        self._reader_top_k = None
        self.discriminator = None

        self.query = query
        if chat_session_id is not None:
            self.chat_session_id = chat_session_id
        if retriever_top_k is not None:
            self.retriever_top_k = retriever_top_k
        if reader_top_k is not None:
            self.reader_top_k = reader_top_k

    @property
    def query(self):
        """Gets the query of this ApplicationTopKQueryRequest.  # noqa: E501


        :return: The query of this ApplicationTopKQueryRequest.  # noqa: E501
        :rtype: str
        """
        return self._query

    @query.setter
    def query(self, query):
        """Sets the query of this ApplicationTopKQueryRequest.


        :param query: The query of this ApplicationTopKQueryRequest.  # noqa: E501
        :type query: str
        """
        if self.local_vars_configuration.client_side_validation and query is None:  # noqa: E501
            raise ValueError("Invalid value for `query`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                query is not None and len(query) < 3):
            raise ValueError("Invalid value for `query`, length must be greater than or equal to `3`")  # noqa: E501

        self._query = query

    @property
    def chat_session_id(self):
        """Gets the chat_session_id of this ApplicationTopKQueryRequest.  # noqa: E501


        :return: The chat_session_id of this ApplicationTopKQueryRequest.  # noqa: E501
        :rtype: str
        """
        return self._chat_session_id

    @chat_session_id.setter
    def chat_session_id(self, chat_session_id):
        """Sets the chat_session_id of this ApplicationTopKQueryRequest.


        :param chat_session_id: The chat_session_id of this ApplicationTopKQueryRequest.  # noqa: E501
        :type chat_session_id: str
        """

        self._chat_session_id = chat_session_id

    @property
    def retriever_top_k(self):
        """Gets the retriever_top_k of this ApplicationTopKQueryRequest.  # noqa: E501


        :return: The retriever_top_k of this ApplicationTopKQueryRequest.  # noqa: E501
        :rtype: int
        """
        return self._retriever_top_k

    @retriever_top_k.setter
    def retriever_top_k(self, retriever_top_k):
        """Sets the retriever_top_k of this ApplicationTopKQueryRequest.


        :param retriever_top_k: The retriever_top_k of this ApplicationTopKQueryRequest.  # noqa: E501
        :type retriever_top_k: int
        """

        self._retriever_top_k = retriever_top_k

    @property
    def reader_top_k(self):
        """Gets the reader_top_k of this ApplicationTopKQueryRequest.  # noqa: E501


        :return: The reader_top_k of this ApplicationTopKQueryRequest.  # noqa: E501
        :rtype: int
        """
        return self._reader_top_k

    @reader_top_k.setter
    def reader_top_k(self, reader_top_k):
        """Sets the reader_top_k of this ApplicationTopKQueryRequest.


        :param reader_top_k: The reader_top_k of this ApplicationTopKQueryRequest.  # noqa: E501
        :type reader_top_k: int
        """

        self._reader_top_k = reader_top_k

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApplicationTopKQueryRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ApplicationTopKQueryRequest):
            return True

        return self.to_dict() != other.to_dict()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['mantium_spec', 'mantium_spec.api', 'mantium_spec.models']

package_data = \
{'': ['*']}

install_requires = \
['openapi-client>=1.1.7,<2.0.0']

setup_kwargs = {
    'name': 'mantium-spec',
    'version': '1.0.976',
    'description': 'OpenAPI-generated Python client',
    'long_description': '# mantium-spec\nMantium API Documentation\n\nThis Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:\n\n- API version: 1.0.976\n- Package version: 1.0.0\n- Build package: org.openapitools.codegen.languages.PythonLegacyClientCodegen\n\n## Requirements.\n\nPython 2.7 and 3.4+\n\n## Installation & Usage\n### pip install\n\nIf the python package is hosted on a repository, you can install directly using:\n\n```sh\npip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git\n```\n(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)\n\nThen import the package:\n```python\nimport mantium_spec\n```\n\n### Setuptools\n\nInstall via [Setuptools](http://pypi.python.org/pypi/setuptools).\n\n```sh\npython setup.py install --user\n```\n(or `sudo python setup.py install` to install the package for all users)\n\nThen import the package:\n```python\nimport mantium_spec\n```\n\n## Getting Started\n\nPlease follow the [installation procedure](#installation--usage) and then run the following:\n\n```python\nfrom __future__ import print_function\n\nimport time\nimport mantium_spec\nfrom mantium_spec.rest import ApiException\nfrom pprint import pprint\n\n# Defining the host is optional and defaults to http://localhost\n# See configuration.py for a list of all supported configuration parameters.\nconfiguration = mantium_spec.Configuration(\n    host = "http://localhost"\n)\n\n# The client must configure the authentication and authorization parameters\n# in accordance with the API server security policy.\n# Examples for each auth method are provided below, use the example that\n# satisfies your auth use case.\n\n# Configure Bearer authorization: HTTPBearer\nconfiguration = mantium_spec.Configuration(\n    access_token = \'YOUR_BEARER_TOKEN\'\n)\n\n\n# Enter a context with an instance of the API client\nwith mantium_spec.ApiClient(configuration) as api_client:\n    # Create an instance of the API class\n    api_instance = mantium_spec.ApplicationsApi(api_client)\n    application_id = \'application_id_example\' # str | \nbody = None # object |  (optional)\n\n    try:\n        # Get application detail.\n        api_response = api_instance.get_application_detail(application_id, body=body)\n        pprint(api_response)\n    except ApiException as e:\n        print("Exception when calling ApplicationsApi->get_application_detail: %s\\n" % e)\n    \n```\n\n## Documentation for API Endpoints\n\nAll URIs are relative to *http://localhost*\n\nClass | Method | HTTP request | Description\n------------ | ------------- | ------------- | -------------\n*ApplicationsApi* | [**get_application_detail**](docs/ApplicationsApi.md#get_application_detail) | **GET** /applications/{application_id} | Get application detail.\n*ApplicationsApi* | [**list_applications**](docs/ApplicationsApi.md#list_applications) | **GET** /applications/ | List applications.\n*ApplicationsApi* | [**query_application**](docs/ApplicationsApi.md#query_application) | **POST** /applications/{application_id}/query | Interact with an application.\n*ApplicationsApi* | [**query_chat_application**](docs/ApplicationsApi.md#query_chat_application) | **POST** /applications/{application_id}/chat | Interact with a chat application.\n\n\n## Documentation For Models\n\n - [APIDataSourceType](docs/APIDataSourceType.md)\n - [Answer](docs/Answer.md)\n - [AnswerMeta](docs/AnswerMeta.md)\n - [ApplicationChatResponse](docs/ApplicationChatResponse.md)\n - [ApplicationCredential](docs/ApplicationCredential.md)\n - [ApplicationDetailResponse](docs/ApplicationDetailResponse.md)\n - [ApplicationQueryRequest](docs/ApplicationQueryRequest.md)\n - [ApplicationQueryResponse](docs/ApplicationQueryResponse.md)\n - [ApplicationResponse](docs/ApplicationResponse.md)\n - [ApplicationStatus](docs/ApplicationStatus.md)\n - [ApplicationTopKQueryRequest](docs/ApplicationTopKQueryRequest.md)\n - [ChatAnswer](docs/ChatAnswer.md)\n - [ChatGPTPluginApplicationDetailResponse](docs/ChatGPTPluginApplicationDetailResponse.md)\n - [Citation](docs/Citation.md)\n - [ContentCreationTemplateOptions](docs/ContentCreationTemplateOptions.md)\n - [ContentType](docs/ContentType.md)\n - [CredentialType](docs/CredentialType.md)\n - [CursorDatamodelPageApplicationResponse](docs/CursorDatamodelPageApplicationResponse.md)\n - [CustomTemplateOptions](docs/CustomTemplateOptions.md)\n - [CustomerSupportTemplateOptions](docs/CustomerSupportTemplateOptions.md)\n - [DataSourceType](docs/DataSourceType.md)\n - [DataSourcesInner](docs/DataSourcesInner.md)\n - [Document](docs/Document.md)\n - [DocumentMetadata](docs/DocumentMetadata.md)\n - [EventPlanningTemplateOptions](docs/EventPlanningTemplateOptions.md)\n - [HTTPValidationError](docs/HTTPValidationError.md)\n - [LegalDocumentsTemplateOptions](docs/LegalDocumentsTemplateOptions.md)\n - [LocationInner](docs/LocationInner.md)\n - [MeetingInfoTemplateOptions](docs/MeetingInfoTemplateOptions.md)\n - [PersonalKnowledgeManagementTemplateOptions](docs/PersonalKnowledgeManagementTemplateOptions.md)\n - [ProductDocumentationTemplateOptions](docs/ProductDocumentationTemplateOptions.md)\n - [RecipeManagementTemplateOptions](docs/RecipeManagementTemplateOptions.md)\n - [ResponseGetApplicationDetail](docs/ResponseGetApplicationDetail.md)\n - [ShopifyTemplateOptions](docs/ShopifyTemplateOptions.md)\n - [Span](docs/Span.md)\n - [Template](docs/Template.md)\n - [ValidationError](docs/ValidationError.md)\n\n\n## Documentation For Authorization\n\n\n## HTTPBearer\n\n- **Type**: Bearer authentication\n\n\n## Author\n\n\n\n\n',
    'author': 'Mantium',
    'author_email': 'support@mantiumai.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7',
}


setup(**setup_kwargs)



# coding: utf-8

"""
    Mantium API

    Mantium API Documentation  # noqa: E501

    The version of the OpenAPI document: 1.0.976
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from mantium_spec.configuration import Configuration


class ResponseGetApplicationDetail(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'created_at': 'datetime',
        'name': 'str',
        'description': 'str',
        'top_k': 'int',
        'status': 'ApplicationStatus',
        'last_synced': 'datetime',
        'storage_size': 'int',
        'data_sources': 'list[DataSourcesInner]',
        'check_permissions': 'bool',
        'similarity_threshold': 'float',
        'destination_id': 'str',
        'embedding_count': 'int',
        'template': 'Template',
        'chatgpt_name': 'str',
        'chatgpt_description': 'str',
        'chatgpt_query_description': 'str',
        'chatgpt_info_description': 'str',
        'logo_url': 'str',
        'contact_email_address': 'str',
        'legal_info_url': 'str',
        'access_token': 'str',
        'saved_response_enabled': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'created_at': 'created_at',
        'name': 'name',
        'description': 'description',
        'top_k': 'top_k',
        'status': 'status',
        'last_synced': 'last_synced',
        'storage_size': 'storage_size',
        'data_sources': 'data_sources',
        'check_permissions': 'check_permissions',
        'similarity_threshold': 'similarity_threshold',
        'destination_id': 'destination_id',
        'embedding_count': 'embedding_count',
        'template': 'template',
        'chatgpt_name': 'chatgpt_name',
        'chatgpt_description': 'chatgpt_description',
        'chatgpt_query_description': 'chatgpt_query_description',
        'chatgpt_info_description': 'chatgpt_info_description',
        'logo_url': 'logo_url',
        'contact_email_address': 'contact_email_address',
        'legal_info_url': 'legal_info_url',
        'access_token': 'access_token',
        'saved_response_enabled': 'saved_response_enabled'
    }

    def __init__(self, id=None, created_at=None, name=None, description=None, top_k=None, status=None, last_synced=None, storage_size=0, data_sources=[], check_permissions=None, similarity_threshold=None, destination_id=None, embedding_count=0, template=None, chatgpt_name=None, chatgpt_description=None, chatgpt_query_description=None, chatgpt_info_description=None, logo_url=None, contact_email_address=None, legal_info_url=None, access_token=None, saved_response_enabled=None, local_vars_configuration=None):  # noqa: E501
        """ResponseGetApplicationDetail - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._created_at = None
        self._name = None
        self._description = None
        self._top_k = None
        self._status = None
        self._last_synced = None
        self._storage_size = None
        self._data_sources = None
        self._check_permissions = None
        self._similarity_threshold = None
        self._destination_id = None
        self._embedding_count = None
        self._template = None
        self._chatgpt_name = None
        self._chatgpt_description = None
        self._chatgpt_query_description = None
        self._chatgpt_info_description = None
        self._logo_url = None
        self._contact_email_address = None
        self._legal_info_url = None
        self._access_token = None
        self._saved_response_enabled = None
        self.discriminator = None

        self.id = id
        self.created_at = created_at
        self.name = name
        self.description = description
        self.top_k = top_k
        self.status = status
        if last_synced is not None:
            self.last_synced = last_synced
        if storage_size is not None:
            self.storage_size = storage_size
        if data_sources is not None:
            self.data_sources = data_sources
        self.check_permissions = check_permissions
        self.similarity_threshold = similarity_threshold
        if destination_id is not None:
            self.destination_id = destination_id
        if embedding_count is not None:
            self.embedding_count = embedding_count
        if template is not None:
            self.template = template
        if chatgpt_name is not None:
            self.chatgpt_name = chatgpt_name
        if chatgpt_description is not None:
            self.chatgpt_description = chatgpt_description
        if chatgpt_query_description is not None:
            self.chatgpt_query_description = chatgpt_query_description
        if chatgpt_info_description is not None:
            self.chatgpt_info_description = chatgpt_info_description
        self.logo_url = logo_url
        self.contact_email_address = contact_email_address
        self.legal_info_url = legal_info_url
        if access_token is not None:
            self.access_token = access_token
        self.saved_response_enabled = saved_response_enabled

    @property
    def id(self):
        """Gets the id of this ResponseGetApplicationDetail.  # noqa: E501

        A unique identifier  # noqa: E501

        :return: The id of this ResponseGetApplicationDetail.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ResponseGetApplicationDetail.

        A unique identifier  # noqa: E501

        :param id: The id of this ResponseGetApplicationDetail.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def created_at(self):
        """Gets the created_at of this ResponseGetApplicationDetail.  # noqa: E501

        Date the application was created  # noqa: E501

        :return: The created_at of this ResponseGetApplicationDetail.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this ResponseGetApplicationDetail.

        Date the application was created  # noqa: E501

        :param created_at: The created_at of this ResponseGetApplicationDetail.  # noqa: E501
        :type created_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def name(self):
        """Gets the name of this ResponseGetApplicationDetail.  # noqa: E501

        Name of the application  # noqa: E501

        :return: The name of this ResponseGetApplicationDetail.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ResponseGetApplicationDetail.

        Name of the application  # noqa: E501

        :param name: The name of this ResponseGetApplicationDetail.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this ResponseGetApplicationDetail.  # noqa: E501

        Description of the application  # noqa: E501

        :return: The description of this ResponseGetApplicationDetail.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ResponseGetApplicationDetail.

        Description of the application  # noqa: E501

        :param description: The description of this ResponseGetApplicationDetail.  # noqa: E501
        :type description: str
        """
        if self.local_vars_configuration.client_side_validation and description is None:  # noqa: E501
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    @property
    def top_k(self):
        """Gets the top_k of this ResponseGetApplicationDetail.  # noqa: E501

        Number of results to return  # noqa: E501

        :return: The top_k of this ResponseGetApplicationDetail.  # noqa: E501
        :rtype: int
        """
        return self._top_k

    @top_k.setter
    def top_k(self, top_k):
        """Sets the top_k of this ResponseGetApplicationDetail.

        Number of results to return  # noqa: E501

        :param top_k: The top_k of this ResponseGetApplicationDetail.  # noqa: E501
        :type top_k: int
        """
        if self.local_vars_configuration.client_side_validation and top_k is None:  # noqa: E501
            raise ValueError("Invalid value for `top_k`, must not be `None`")  # noqa: E501

        self._top_k = top_k

    @property
    def status(self):
        """Gets the status of this ResponseGetApplicationDetail.  # noqa: E501


        :return: The status of this ResponseGetApplicationDetail.  # noqa: E501
        :rtype: ApplicationStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ResponseGetApplicationDetail.


        :param status: The status of this ResponseGetApplicationDetail.  # noqa: E501
        :type status: ApplicationStatus
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def last_synced(self):
        """Gets the last_synced of this ResponseGetApplicationDetail.  # noqa: E501

        The last time a DatasetUpdate job ran for the application  # noqa: E501

        :return: The last_synced of this ResponseGetApplicationDetail.  # noqa: E501
        :rtype: datetime
        """
        return self._last_synced

    @last_synced.setter
    def last_synced(self, last_synced):
        """Sets the last_synced of this ResponseGetApplicationDetail.

        The last time a DatasetUpdate job ran for the application  # noqa: E501

        :param last_synced: The last_synced of this ResponseGetApplicationDetail.  # noqa: E501
        :type last_synced: datetime
        """

        self._last_synced = last_synced

    @property
    def storage_size(self):
        """Gets the storage_size of this ResponseGetApplicationDetail.  # noqa: E501

        current file storage size for the application  # noqa: E501

        :return: The storage_size of this ResponseGetApplicationDetail.  # noqa: E501
        :rtype: int
        """
        return self._storage_size

    @storage_size.setter
    def storage_size(self, storage_size):
        """Sets the storage_size of this ResponseGetApplicationDetail.

        current file storage size for the application  # noqa: E501

        :param storage_size: The storage_size of this ResponseGetApplicationDetail.  # noqa: E501
        :type storage_size: int
        """

        self._storage_size = storage_size

    @property
    def data_sources(self):
        """Gets the data_sources of this ResponseGetApplicationDetail.  # noqa: E501

        Data sources used by the application  # noqa: E501

        :return: The data_sources of this ResponseGetApplicationDetail.  # noqa: E501
        :rtype: list[DataSourcesInner]
        """
        return self._data_sources

    @data_sources.setter
    def data_sources(self, data_sources):
        """Sets the data_sources of this ResponseGetApplicationDetail.

        Data sources used by the application  # noqa: E501

        :param data_sources: The data_sources of this ResponseGetApplicationDetail.  # noqa: E501
        :type data_sources: list[DataSourcesInner]
        """

        self._data_sources = data_sources

    @property
    def check_permissions(self):
        """Gets the check_permissions of this ResponseGetApplicationDetail.  # noqa: E501

        Whether or not application queries check document permissions  # noqa: E501

        :return: The check_permissions of this ResponseGetApplicationDetail.  # noqa: E501
        :rtype: bool
        """
        return self._check_permissions

    @check_permissions.setter
    def check_permissions(self, check_permissions):
        """Sets the check_permissions of this ResponseGetApplicationDetail.

        Whether or not application queries check document permissions  # noqa: E501

        :param check_permissions: The check_permissions of this ResponseGetApplicationDetail.  # noqa: E501
        :type check_permissions: bool
        """
        if self.local_vars_configuration.client_side_validation and check_permissions is None:  # noqa: E501
            raise ValueError("Invalid value for `check_permissions`, must not be `None`")  # noqa: E501

        self._check_permissions = check_permissions

    @property
    def similarity_threshold(self):
        """Gets the similarity_threshold of this ResponseGetApplicationDetail.  # noqa: E501

        (Experimental) How close must an authorized document score be to the lowest overall top k document score to be considered a match for the query  # noqa: E501

        :return: The similarity_threshold of this ResponseGetApplicationDetail.  # noqa: E501
        :rtype: float
        """
        return self._similarity_threshold

    @similarity_threshold.setter
    def similarity_threshold(self, similarity_threshold):
        """Sets the similarity_threshold of this ResponseGetApplicationDetail.

        (Experimental) How close must an authorized document score be to the lowest overall top k document score to be considered a match for the query  # noqa: E501

        :param similarity_threshold: The similarity_threshold of this ResponseGetApplicationDetail.  # noqa: E501
        :type similarity_threshold: float
        """
        if self.local_vars_configuration.client_side_validation and similarity_threshold is None:  # noqa: E501
            raise ValueError("Invalid value for `similarity_threshold`, must not be `None`")  # noqa: E501

        self._similarity_threshold = similarity_threshold

    @property
    def destination_id(self):
        """Gets the destination_id of this ResponseGetApplicationDetail.  # noqa: E501

        Destination identifier  # noqa: E501

        :return: The destination_id of this ResponseGetApplicationDetail.  # noqa: E501
        :rtype: str
        """
        return self._destination_id

    @destination_id.setter
    def destination_id(self, destination_id):
        """Sets the destination_id of this ResponseGetApplicationDetail.

        Destination identifier  # noqa: E501

        :param destination_id: The destination_id of this ResponseGetApplicationDetail.  # noqa: E501
        :type destination_id: str
        """

        self._destination_id = destination_id

    @property
    def embedding_count(self):
        """Gets the embedding_count of this ResponseGetApplicationDetail.  # noqa: E501

        Number of embeddings in the destination  # noqa: E501

        :return: The embedding_count of this ResponseGetApplicationDetail.  # noqa: E501
        :rtype: int
        """
        return self._embedding_count

    @embedding_count.setter
    def embedding_count(self, embedding_count):
        """Sets the embedding_count of this ResponseGetApplicationDetail.

        Number of embeddings in the destination  # noqa: E501

        :param embedding_count: The embedding_count of this ResponseGetApplicationDetail.  # noqa: E501
        :type embedding_count: int
        """
        if (self.local_vars_configuration.client_side_validation and
                embedding_count is not None and embedding_count < 0):  # noqa: E501
            raise ValueError("Invalid value for `embedding_count`, must be a value greater than or equal to `0`")  # noqa: E501

        self._embedding_count = embedding_count

    @property
    def template(self):
        """Gets the template of this ResponseGetApplicationDetail.  # noqa: E501


        :return: The template of this ResponseGetApplicationDetail.  # noqa: E501
        :rtype: Template
        """
        return self._template

    @template.setter
    def template(self, template):
        """Sets the template of this ResponseGetApplicationDetail.


        :param template: The template of this ResponseGetApplicationDetail.  # noqa: E501
        :type template: Template
        """

        self._template = template

    @property
    def chatgpt_name(self):
        """Gets the chatgpt_name of this ResponseGetApplicationDetail.  # noqa: E501

        Name of the application intended for ChatGPT consumption  # noqa: E501

        :return: The chatgpt_name of this ResponseGetApplicationDetail.  # noqa: E501
        :rtype: str
        """
        return self._chatgpt_name

    @chatgpt_name.setter
    def chatgpt_name(self, chatgpt_name):
        """Sets the chatgpt_name of this ResponseGetApplicationDetail.

        Name of the application intended for ChatGPT consumption  # noqa: E501

        :param chatgpt_name: The chatgpt_name of this ResponseGetApplicationDetail.  # noqa: E501
        :type chatgpt_name: str
        """

        self._chatgpt_name = chatgpt_name

    @property
    def chatgpt_description(self):
        """Gets the chatgpt_description of this ResponseGetApplicationDetail.  # noqa: E501

        Description of the application intended for ChatGPT consumption. This is a prompt  # noqa: E501

        :return: The chatgpt_description of this ResponseGetApplicationDetail.  # noqa: E501
        :rtype: str
        """
        return self._chatgpt_description

    @chatgpt_description.setter
    def chatgpt_description(self, chatgpt_description):
        """Sets the chatgpt_description of this ResponseGetApplicationDetail.

        Description of the application intended for ChatGPT consumption. This is a prompt  # noqa: E501

        :param chatgpt_description: The chatgpt_description of this ResponseGetApplicationDetail.  # noqa: E501
        :type chatgpt_description: str
        """

        self._chatgpt_description = chatgpt_description

    @property
    def chatgpt_query_description(self):
        """Gets the chatgpt_query_description of this ResponseGetApplicationDetail.  # noqa: E501

        The description used in the openai.yaml manifest for the /query endpoint  # noqa: E501

        :return: The chatgpt_query_description of this ResponseGetApplicationDetail.  # noqa: E501
        :rtype: str
        """
        return self._chatgpt_query_description

    @chatgpt_query_description.setter
    def chatgpt_query_description(self, chatgpt_query_description):
        """Sets the chatgpt_query_description of this ResponseGetApplicationDetail.

        The description used in the openai.yaml manifest for the /query endpoint  # noqa: E501

        :param chatgpt_query_description: The chatgpt_query_description of this ResponseGetApplicationDetail.  # noqa: E501
        :type chatgpt_query_description: str
        """

        self._chatgpt_query_description = chatgpt_query_description

    @property
    def chatgpt_info_description(self):
        """Gets the chatgpt_info_description of this ResponseGetApplicationDetail.  # noqa: E501

        The top-level description used in the openai.yaml manifest  # noqa: E501

        :return: The chatgpt_info_description of this ResponseGetApplicationDetail.  # noqa: E501
        :rtype: str
        """
        return self._chatgpt_info_description

    @chatgpt_info_description.setter
    def chatgpt_info_description(self, chatgpt_info_description):
        """Sets the chatgpt_info_description of this ResponseGetApplicationDetail.

        The top-level description used in the openai.yaml manifest  # noqa: E501

        :param chatgpt_info_description: The chatgpt_info_description of this ResponseGetApplicationDetail.  # noqa: E501
        :type chatgpt_info_description: str
        """

        self._chatgpt_info_description = chatgpt_info_description

    @property
    def logo_url(self):
        """Gets the logo_url of this ResponseGetApplicationDetail.  # noqa: E501

        URL of the application logo  # noqa: E501

        :return: The logo_url of this ResponseGetApplicationDetail.  # noqa: E501
        :rtype: str
        """
        return self._logo_url

    @logo_url.setter
    def logo_url(self, logo_url):
        """Sets the logo_url of this ResponseGetApplicationDetail.

        URL of the application logo  # noqa: E501

        :param logo_url: The logo_url of this ResponseGetApplicationDetail.  # noqa: E501
        :type logo_url: str
        """
        if self.local_vars_configuration.client_side_validation and logo_url is None:  # noqa: E501
            raise ValueError("Invalid value for `logo_url`, must not be `None`")  # noqa: E501

        self._logo_url = logo_url

    @property
    def contact_email_address(self):
        """Gets the contact_email_address of this ResponseGetApplicationDetail.  # noqa: E501

        Contact email address for the plugin  # noqa: E501

        :return: The contact_email_address of this ResponseGetApplicationDetail.  # noqa: E501
        :rtype: str
        """
        return self._contact_email_address

    @contact_email_address.setter
    def contact_email_address(self, contact_email_address):
        """Sets the contact_email_address of this ResponseGetApplicationDetail.

        Contact email address for the plugin  # noqa: E501

        :param contact_email_address: The contact_email_address of this ResponseGetApplicationDetail.  # noqa: E501
        :type contact_email_address: str
        """
        if self.local_vars_configuration.client_side_validation and contact_email_address is None:  # noqa: E501
            raise ValueError("Invalid value for `contact_email_address`, must not be `None`")  # noqa: E501

        self._contact_email_address = contact_email_address

    @property
    def legal_info_url(self):
        """Gets the legal_info_url of this ResponseGetApplicationDetail.  # noqa: E501

        URL to the legal information for the plugin  # noqa: E501

        :return: The legal_info_url of this ResponseGetApplicationDetail.  # noqa: E501
        :rtype: str
        """
        return self._legal_info_url

    @legal_info_url.setter
    def legal_info_url(self, legal_info_url):
        """Sets the legal_info_url of this ResponseGetApplicationDetail.

        URL to the legal information for the plugin  # noqa: E501

        :param legal_info_url: The legal_info_url of this ResponseGetApplicationDetail.  # noqa: E501
        :type legal_info_url: str
        """
        if self.local_vars_configuration.client_side_validation and legal_info_url is None:  # noqa: E501
            raise ValueError("Invalid value for `legal_info_url`, must not be `None`")  # noqa: E501

        self._legal_info_url = legal_info_url

    @property
    def access_token(self):
        """Gets the access_token of this ResponseGetApplicationDetail.  # noqa: E501

        Access token for the plugin  # noqa: E501

        :return: The access_token of this ResponseGetApplicationDetail.  # noqa: E501
        :rtype: str
        """
        return self._access_token

    @access_token.setter
    def access_token(self, access_token):
        """Sets the access_token of this ResponseGetApplicationDetail.

        Access token for the plugin  # noqa: E501

        :param access_token: The access_token of this ResponseGetApplicationDetail.  # noqa: E501
        :type access_token: str
        """

        self._access_token = access_token

    @property
    def saved_response_enabled(self):
        """Gets the saved_response_enabled of this ResponseGetApplicationDetail.  # noqa: E501

        Whether saved responses are enabled  # noqa: E501

        :return: The saved_response_enabled of this ResponseGetApplicationDetail.  # noqa: E501
        :rtype: bool
        """
        return self._saved_response_enabled

    @saved_response_enabled.setter
    def saved_response_enabled(self, saved_response_enabled):
        """Sets the saved_response_enabled of this ResponseGetApplicationDetail.

        Whether saved responses are enabled  # noqa: E501

        :param saved_response_enabled: The saved_response_enabled of this ResponseGetApplicationDetail.  # noqa: E501
        :type saved_response_enabled: bool
        """
        if self.local_vars_configuration.client_side_validation and saved_response_enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `saved_response_enabled`, must not be `None`")  # noqa: E501

        self._saved_response_enabled = saved_response_enabled

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseGetApplicationDetail):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResponseGetApplicationDetail):
            return True

        return self.to_dict() != other.to_dict()
